@@ -1,23 +1,24 @@
 import socket
 import keyboard
+import time
 
 from threading import Thread
 
 
 class LiteNetClient:
-    def __init__(self, ip, port=5050, header=64, encoding="utf-8"):
+    def __init__(self, ip, port=5050, header=64, encoding="utf-8", debug=False):
         self.ip, self.port = ip, port
 
         self.header, self.encoding = header, encoding
 
         self._close_msg = "[CLOSE]"
 
-        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-
         socket.setdefaulttimeout(5)
 
         keyboard.add_hotkey("t", self.message)
 
+        self.debug = debug
+
         self._temp = None
 
     def start(self):
@@ -44,7 +45,8 @@ class LiteNetClient:
 
         except socket.error:
             print("Server has closed connection your with the server.")
-            return None
+            time.sleep(2)
+            exit()
 
     def send(self, msg):
         msg = msg.encode(self.encoding)
@@ -52,15 +54,17 @@ class LiteNetClient:
         send_length = str(msg_length).encode(self.encoding) + b' ' * (self.header - len(str(msg_length).encode(self.encoding)))
         self.socket.send(send_length)
         self.socket.send(msg)
-        print("[DEBUG] Message Sent")
+        if self.debug:
+            print("[DEBUG] Message Sent")
 
     def _start(self):
+        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+
         self.socket.connect((self.ip, self.port))
         print(f"Connected to {self.ip}:{self.port}")
 
         while True:
             server_msg = self.get_server_msg()
-
             if server_msg:
                 print(server_msg)
 
