@@ -50,7 +50,14 @@ class LiteNetServer:
         }
 
         while self.clients[addr]["alive"]:
-            msg_length = self.clients[addr]["connection"].recv(self.header)
+            try:
+                msg_length = self.clients[addr]["connection"].recv(self.header)
+            except OSError:
+                print(f"Connection has been closed by {addr[0]}:{addr[1]}")
+                print(self.clients)
+                input("Continue?")
+                break
+
             if msg_length:
                 msg_length = int(msg_length.decode(self.encoding))
 
