@@ -1,5 +1,5 @@
 def to_liteaddr(ip):
-    ip = ip.split(".")
+    ip = ip[0].split(".")
     return "Lite|" + "_".join([int_to_lite_num(int(n)) for n in ip])
 
 
